<!--- 
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT Calendar directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2010-2016.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files 
in this directory, you agree to the terms and conditions of the applicable 
end user license agreement.
--->
<!---
/* *************************************************************** */
Author: 	
	PaperThin Inc.
	G. Cronkright
Name:
	calendar_category_checkbox_display_rh.cfm
Summary:
	Render Handler to render out the category checkboxes for the calendar views
	gets the required data and include the calendar_category_checkbox_list_rh.cfm
ADF App:
	pt_calendar
Version:
	4.0
History:
	2013-09-26 - GAC - Created
	2015-09-28 - GAC - Added the request.element.hasData  flag to tell commonspot to always rebuild this renderhandler.
	2016-02-23 - DRM - Resource detection exit
--->

<!--- if this module loads resources, do it here.. --->
<!---<cfscript>
	// none
</cfscript>--->

<!--- ... then exit if all we're doing is detecting required resources --->
<cfif Request.RenderState.RenderMode EQ "getResources">
  <cfexit>
</cfif>


<cfscript>
	// This script MUST remain dynamic since the generated HTML is modified with a URL parameters
	request.element.isStatic = 0;
	request.element.hasData = 1;
	
	// Get the Configuration and Page Map Values
	appConfig = application.ptCalendar.getAppConfig();
	
	// Set the Event Cache status from the configuration element
	useEventsCache = application.ptCalendar.getEventCacheStatus();
		
	// Get the items from the Display Properties Custom Element
	items = attributes.elementInfo.elementData.propertyValues;

	/* ** ptCalendar getRenderEventFilteredCategoryData SETTINGS *** */
	//  -- THIS MUST ME INCLUDED AT THE TOP OF THE calendar_category_checkbox_list_rh RenderHandler (before getRenderEventFilteredCategoryData)
	// - ptCalendar Events Date Range designation 
	viewRangeType = "Month";  // (Month/Week/Day)
	
	// Set the view param defaults
	currViewType = application.ptCalendar.getDefaultDisplayView();
	viewParamName = application.ptCalendar.getViewParamName();
	
	if ( StructKeyExists(request,"params") AND StructKeyExists(request.params,viewParamName) )
		currViewType = request.params[viewParamName];
	
	// Chenge the Range base on the VIEW that is being displayed
	switch(currViewType) {
		case "monthgrid": case "monthlist":
	         viewRangeType = "Month"; 
	         break;
	    case "weekgrid": case "weeklist":
		     viewRangeType = "Week"; 
	         break;
	    case "daylist":
	         viewRangeType = "Day"; 
	         break;
	    default: 
	         viewRangeType = "Month";  // (Month/Week/Day)
	}

	// - ptCalendar EventsCache designation (generally this will be true. May need to set to false for debugging)
	// useEventsCache = false; // (true/false) - Use this as an override for the Global setting that is managed via the Configuration element
	
	/* ** getRenderEventFilteredCategoryData SETTINGS *** */
	// ptCalendar date and data processing the calendar renderhandler return as CF query object
	//  -- THIS MUST BE INCLUDED AT THE TOP OF THE ptCalendar GRID/LIST RenderHandlers (after the getRenderEventData Settings)
	eventCategoryData = application.ptCalendar.calRenderController.getRenderEventFilteredCategoryData(
																			displayPropsArray=items
																			,viewRangeType=viewRangeType
																			,useEventsCache=useEventsCache
																		);

	// Set the category items request variable to be shared with the Calegory Checkbox list render handler
	request.ptCalendar.category.items = eventCategoryData;
	
	// Get the Display view Render Handler Path Structure
	rhFileName = "calendar_category_checkbox_list_rh.cfm";
	
	rhDefaultFilePath = application.ptCalendar.calRenderViewDAO.getCalendarDisplayViewDefaultRHFolderPath();
	rhOverRideFilePath = application.ptCalendar.calRenderViewDAO.getCalendarDisplayViewOverrideRHFolderPath();
	
	rhDefaultFilePath = rhDefaultFilePath & rhFileName;
	rhOverRideFilePath = rhOverRideFilePath & rhFileName;
	
	retRHFilePath = "";
	// Get the Calendar Event Categories Render Handler Path;
	if ( FileExists(ExpandPath(rhOverRideFilePath)) )
		retRHFilePath = rhOverRideFilePath;
	else if ( FileExists(ExpandPath(rhDefaultFilePath)) )
		retRHFilePath = rhDefaultFilePath;
</cfscript>

<!--- // DO NOT Display the Category Header if there no categories to list  --->
<cfif ArrayLen(request.ptCalendar.category.items)>
	<!--- // Include the RH file, if a valid path for the provided view --->
	<cfif LEN(TRIM(retRHFilePath))>
		<cfinclude template="#retRHFilePath#">
	<cfelse>
		<cfoutput><div><strong>The calendar event categories list render handler could not be found!</strong></div></cfoutput>
	</cfif>
</cfif>	
	